-- return;

_ = [[
@title:			Shop categories MoreRealistic
@description:	Moves MoreRealistic mods into a separate main category in the shop.
@author:		Jakob Tischler
@date:			01 Apr 2014
@version:		0.2

@contact:		jakobgithub -ätt- gmail -dot- com
]]

--[[
TODO: find a better way to get from storeItem to vehicleType
]]
------------------------------------

ShopCatMr = {}
ShopCatMr.modDir = g_currentModDirectory;
addModEventListener(ShopCatMr);


function ShopCatMr:loadMap(name)
	print('## Shop categories MoreRealistic v0.2 by Jakob Tischler loaded');
	local modsDirLen = g_modsDirectory:len();


	-- SET VEHICLES' CATEGORY
	local realisticVehicleSpec = SpecializationUtil.getSpecialization('realisticVehicle');
	for i,item in ipairs(StoreItemsUtil.storeItems) do
		item.isMR = false;

		-- CHECK IF MOD IS MR
		if item.isMod then
			local isMR = false;
			if fileExists(item.xmlFilename) then
				local xmlFile = loadXMLFile('tmpXML', item.xmlFilename);
				local typeName = getXMLString(xmlFile, 'vehicle#type');
				delete(xmlFile);
				if typeName then
					if Utils.startsWith(typeName, 'moreRealistic') then -- CHECK 1: typeName starts with 'moreRealistic'
						isMR = true;
					else
						local custEnv = item.xmlFilename:sub(modsDirLen + 2, item.xmlFilename:len());
						if Utils.startsWith(custEnv, 'mr') then -- CHECK 2: mod filename starts with 'mr'
							isMR = true;
						else
							custEnv = Utils.splitString('/', custEnv)[1];
							local vehicleType = custEnv .. '.' .. typeName;
							if VehicleTypeUtil.vehicleTypes[vehicleType] and Utils.hasListElement(VehicleTypeUtil.vehicleTypes[vehicleType].specializations, realisticVehicleSpec) then -- CHECK 3: vehicleType has 'realisticVehicle' specialization
								isMR = true;
							end;
						end;
					end;
				end;
			end;

			if not isMR and item.name then -- CHECK 4: vehicle name starts with 'MR '
				isMR = Utils.startsWith(item.name:lower(), 'mr ');
			end;

			item.isMR = isMR;
		end;
	end;


	-- ====================================================================


	local tableCopy = function(tab, recursive)
		local result = {};
		for k,v in pairs(tab) do
			if recursive and type(v) == 'table' then
				result[k] = tableCopy(v, recursive);
			else
				result[k] = v;
			end;
		end;
		return result;
	end;

	-- CREATE NEW MAIN MR CATEGORY
	ShopScreen.CATEGORY_MODS_MR_MACHINE_TYPES = ShopScreen.CATEGORY_MODS_MACHINE_TYPES + 1;
	ShopScreen.CATEGORY_MODS_BRANDS = ShopScreen.CATEGORY_MODS_MR_MACHINE_TYPES + 1;
	ShopScreen.CATEGORY_MODS_PLACEABLES = ShopScreen.CATEGORY_MODS_BRANDS + 1;
	ShopScreen.CATEGORY_SALES = ShopScreen.CATEGORY_MODS_PLACEABLES + 1;
	ShopScreen.CATEGORY_OWNED = ShopScreen.CATEGORY_SALES + 1;

	table.insert(g_shopScreen.categoryList, ShopScreen.CATEGORY_MODS_MR_MACHINE_TYPES, 'category_modsMachineTypeMR');
	g_i18n.globalI18N.texts.category_modsMachineTypeMR = g_i18n:getText('category_modsMachineType') .. ' (MR)';

	local modSubCategoryList = tableCopy(g_shopScreen.subCategoryList[ShopScreen.CATEGORY_MODS_MACHINE_TYPES]);
	table.insert(g_shopScreen.subCategoryList, ShopScreen.CATEGORY_MODS_MR_MACHINE_TYPES, modSubCategoryList);

	g_shopScreen:categorySelectionOnCreate(g_shopScreen.categorySelectionElement); -- UPDATE CATEGORY SELECTION TITLES
	g_shopScreen:subCategorySelectionOnCreate(g_shopScreen.subCategorySelectionElement); -- UPDATE SUBCATEGORY SELECTION TITLES

	-- DISPLAY MR MODS SEPARATELY IN SHOP
	local updateMrModsMachineTypeSubCategoryList = function(self) -- GET SUBCATEGORY LIST FROM DEFAULT MODS CATEGORY
		self.subCategoryList[ShopScreen.CATEGORY_MODS_MR_MACHINE_TYPES] = tableCopy(self.subCategoryList[ShopScreen.CATEGORY_MODS_MACHINE_TYPES], true);
	end;
	ShopScreen.updateModsMachineTypeSubCategoryList = Utils.appendedFunction(ShopScreen.updateModsMachineTypeSubCategoryList, updateMrModsMachineTypeSubCategoryList);

	local updateShopItemListOrig = ShopScreen.updateShopItemList;
	function ShopScreen.updateShopItemList(self)
		local catIsMods, catIsModsMR = self.selectedCategory == ShopScreen.CATEGORY_MODS_MACHINE_TYPES, self.selectedCategory == ShopScreen.CATEGORY_MODS_MR_MACHINE_TYPES;
		if catIsMods or catIsModsMR then
			self.shopItemList:deleteListItems();
			self.currentStoreItemsList = {};
			for i=1, #StoreItemsUtil.storeItems do
				self.currentItem = StoreItemsUtil.storeItems[i];
				if self.currentItem.isMod and self.currentItem.isMR == catIsModsMR and self.subCategoryList[self.selectedCategory][self.selectedSubCategory] == 'subCategory_' .. self.currentItem.machineType then
					local li = self.listItemTemplate:clone(self.shopItemList):updateAbsolutePosition();
					self.currentStoreItemsList[#self.currentStoreItemsList + 1] = self.currentItem;
				end;
			end;
			self.currentItem = nil;

		else
			updateShopItemListOrig(self);
		end;
	end;
end;

function ShopCatMr:deleteMap()
end;

function ShopCatMr:keyEvent(unicode, sym, modifier, isDown)
end;

function ShopCatMr:update(dt)
end;

function ShopCatMr:updateTick(dt)
end;

function ShopCatMr:draw()
end;

function ShopCatMr:mouseEvent(posX, posY, isDown, isUp, mouseButton)
end;
